@@ -1,4 +1,4 @@
-__all__ = ['AnyPosixPath', 'Path', 'StdIOE', 'StdOE', 'Table']
+__all__ = ['AnyPosixPath', 'Path', 'Row', 'Std', 'Table']
 
 
 import pathlib as p
@@ -10,10 +10,18 @@ if t.TYPE_CHECKING:
 
 AnyPosixPath = t.Union[p.Path, 'RemotePath']
 Path = t.Union[str, p.Path]
-StdIOE = t.Tuple[bytes, bytes, bytes]
-StdOE = t.Tuple[bytes, bytes]
+
+
+class Std(t.NamedTuple):
+    out: bytes
+    err: bytes
+
+
+class Row:
+    def __class_getitem__(cls, T: type) -> type:
+        return t.Dict[str, T]
 
 
 class Table:
     def __class_getitem__(cls, T: type) -> type:
-        return t.List[t.Dict[str, T]]
+        return t.List[Row[T]]
