@@ -1,5 +1,4 @@
-'''Generic implementation
-'''
+'''Generic implementation'''
 
 
 __all__ = ['CacheClear', 'Generic', 'New']
@@ -13,8 +12,7 @@ if t.TYPE_CHECKING:
 
 
 class CacheClear:
-    '''`functools._lru_cache_wrapper.cache_clear`
-    '''
+    '''`functools._lru_cache_wrapper.cache_clear`'''
 
     def cache_clear(self) -> 'Self':
         self._cache_clear()
@@ -29,8 +27,7 @@ class CacheClear:
 
 
 class New:
-    '''Object constructor
-    '''
+    '''Object constructor'''
 
     @classmethod
     def new(cls, *args, **kwargs) -> 'Self':
